@@ -26,13 +26,13 @@ def prefect_parameter_read_json(path,param_name):
 
 
 @prefect.task
-def generate_time_range(start,end,output_format='%Y-%m-%dT%H:%M:%S'):
+def generate_time_range(start,end,
+                        output_format='%Y-%m-%dT%H:%M:%S',
+                        output_type='string'):
     logger = logging.getLogger(__name__)
-    generated_time_range = utils.time(output_format=output_format).get_time_range(start=start,end=end)
-
-    logger.info(f"generated_time_range{generated_time_range}")
-    return generated_time_range
-
+    generated_time_range = utils.time(output_format=output_format,
+                                      output_type=output_type).get_time_range(start=start,
+                                                                              end=end)
 @prefect.task
 def pull_dbt_repo(git_token_name,
                   repository_path,
